enumShadowTableState
enum ShadowTableState
Describes how much table context is available in the shadow store.
Cases
case Missingcase Materializedcase InitializedTest cases 3
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 2
Relations
Constant reads 3
- class-const ZtdQuery\Shadow\ShadowStore::state() packages/ztd-query-core/src/Shadow/ShadowStore.php:89
- class-const ZtdQuery\Shadow\ShadowStore::state() packages/ztd-query-core/src/Shadow/ShadowStore.php:93
- class-const ZtdQuery\Shadow\ShadowStore::state() packages/ztd-query-core/src/Shadow/ShadowStore.php:96